
subroutine getparameters(N, maxits, tolerance, printfrequency, showplate, method)
!------------------------------------------------------------------------------------
! Read in the problem size and iteration control parameters. A few checks are made,
! and the show stops if a parameter is No Good(TM). An arbitrary limit of N <= 20000
! has been imposed since it is unlikely you want to exceed that on a single machine.
! The memory requirements are more than 2*N*N doubles or 16*N^2/1.0e9 Gbytes. That
! means
!   N = 20000 implies 6.4 Gbytes
!   N = 28000 implies 12.5 Gbytes
!
! Furthermore, the initial algorithm would take forever on that size of problem.
!
! The variables are defined and explained in main.f90. One that is not used yet is
! "method", which refers to the 7 different ways I've found to do this in Fortran.
!
!-----------------
! Randall Bramley
! Department of Computer Science
! Indiana University, Bloomington
!----------------------
! Started: Fri 03 Feb 2017, 06:22 PM
! Last Modified: Wed 24 Jan 2018, 07:44 AM
!------------------------------------------------------------------------------------

    use iso_fortran_env, only: stdout => output_unit, stderr => error_unit, &
                               real8 => real64
    implicit none
    integer            :: N, maxits, printfrequency, errorflag, parameters, method
    real(kind=real8)   :: tolerance
    logical :: showplate

    open(newunit=parameters, file='parameters', action='read', status='old', iostat=errorflag)
    if (errorflag /= 0) then
        write(unit=stderr,fmt=666) 'Unable to open file "parameters"; bailing out'
        stop
    end if
    read(unit=parameters, fmt=*) N, maxits, tolerance, printfrequency, showplate, method
    close(unit=parameters)

    if (N  <=  1) then
        write(unit=stderr,fmt=777) 'Invalid N = ', N, ', you twit. Try again.'
        stop
    end if 

    if (N  >  20000) then
        write(unit=stderr,fmt=777) 'N = ', N, ', is probably too large. Reset it.'
        stop
    end if 

    if (maxits  <  1) then
        write(unit=stderr,fmt=777) 'Invalid maxits = ', maxits, ', try again.'
        stop
    end if 

    if (tolerance <  1.0e-16_real8) then
        write(unit=stderr,fmt=888) 'Invalid tolerance = ', tolerance, ', try again.'
        stop
    end if 

    if (method <  1 .or. method > 7) then
        write(unit=stderr,fmt=777) 'Invalid method = ', method, ', try again.'
        stop
    end if 

    666 format(a)
    777 format(a,i0,a)
    888 format(a,es12.4,a)

    return

end subroutine getparameters
